==> release.12.0.73.1.tgz: prontus/cpan/js-local/ComunesPass.class.js <==
var ComunesPass = {
    validaPwd: function(objeto) {
        //valores por defecto
        var largo_max = 32;
        var largo_min = 8;

        // intentamos leer la var global con los valores especificos de este Prontus
        if (typeof ProntusConf !== 'undefined' && ProntusConf['psw-max-length'] > 0) {
            largo_max = ProntusConf['psw-max-length'];
        }
        if (typeof ProntusConf !== 'undefined' && ProntusConf['psw-min-length'] > 0) {
            largo_min = ProntusConf['psw-min-length'];
        }

        if ($('#_new_psw').val() == '') {
            objeto.mostrarAlerta('Debes ingresar la nueva contraseña');
            $('#_new_psw').focus();
            return false;
        }
        if ($('#_new_psw').val().length < largo_min) {
            objeto.mostrarAlerta('La contraseña debe tener al menos ' + largo_min + ' caracteres.');
            $('#_new_psw').focus();
            return false;
        }
        if ($('#_new_psw').val().length > largo_max) {
            objeto.mostrarAlerta('La contraseña no debe tener más de ' + largo_max + ' caracteres.');
            $('#_new_psw').focus();
            return false;
        }
        if ($('#_new_psw_confirm').val() == '') {
            objeto.mostrarAlerta('Debes confirmar la nueva contraseña');
            $('#_new_psw_confirm').focus();
            return false;
        }
        if ($('#_new_psw').val() != $('#_new_psw_confirm').val()) {
            objeto.mostrarAlerta('Las contraseñas no coinciden');
            $('#_new_psw_confirm').focus();
            return false;
        }

        $('#box-alert').hide();
        return true;
    }
};

==> release.12.3.1.2.tgz: prontus/cpan/js-local/ComunesPass.class.js <==
var ComunesPass = {
    validaPwd: function(objeto) {
        //valores por defecto
        var largo_max = 32;
        var largo_min = 8;

        // intentamos leer la var global con los valores especificos de este Prontus
        if (typeof ProntusConf !== 'undefined' && ProntusConf['psw-max-length'] > 0) {
            largo_max = ProntusConf['psw-max-length'];
        }
        if (typeof ProntusConf !== 'undefined' && ProntusConf['psw-min-length'] > 0) {
            largo_min = ProntusConf['psw-min-length'];
        }

        if ($('#_new_psw').val() == '') {
            objeto.mostrarAlerta(ProntusL10n.get('comunespass_input_new_pass'));
            $('#_new_psw').focus();
            return false;
        }
        if ($('#_new_psw').val().length < largo_min) {
            objeto.mostrarAlerta(ProntusL10n.get('comunespass_new_pass_minlen', largo_min));
            $('#_new_psw').focus();
            return false;
        }
        if ($('#_new_psw').val().length > largo_max) {
            objeto.mostrarAlerta(ProntusL10n.get('comunespass_new_pass_maxlen', largo_max));
            $('#_new_psw').focus();
            return false;
        }
        if ($('#_new_psw_confirm').val() == '') {
            objeto.mostrarAlerta(ProntusL10n.get('comunespass_new_pass_confirm'));
            $('#_new_psw_confirm').focus();
            return false;
        }
        if ($('#_new_psw').val() != $('#_new_psw_confirm').val()) {
            objeto.mostrarAlerta(ProntusL10n.get('comunespass_pass_mismatch'));
            $('#_new_psw_confirm').focus();
            return false;
        }

        $('#box-alert').hide();
        return true;
    }
};
